(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     38663,       1127]*)
(*NotebookOutlinePosition[     99510,       2916]*)
(*  CellTagsIndexPosition[     98997,       2898]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["CSSSave` Package", "Title",
  CellTags->"CSSSave`"],

Cell["Version 1.0", "Subtitle",
  CellTags->"CSSSave`"],

Cell["\<\
\[Copyright] 1999, Reinhold Kainhofer, reinhold.kainhofer@kfunigraz.ac.at\
\>", "Author",
  CellTags->"CSSSave`"],

Cell[TextData[{
  ButtonBox["General",
    ButtonData:>"General",
    Active->True,
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["License and forbidden uses",
    ButtonData:>"License and forbidden uses",
    Active->True,
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["Downloading\n",
    ButtonData:>"Downloading",
    Active->True,
    ButtonStyle->"Hyperlink"],
  ButtonBox["Installing and Using the package\n",
    ButtonData:>"Installing and Using the package",
    Active->True,
    ButtonStyle->"Hyperlink"],
  ButtonBox["Known Bugs / Limitations / Flaws",
    ButtonData:>"Known Bugs / Limitations / Flaws",
    Active->True,
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["History",
    ButtonData:>"History",
    Active->True,
    ButtonStyle->"Hyperlink"],
  " ",
  ButtonBox["\n",
    ButtonData:>"Installing and Using the package",
    Active->True,
    ButtonStyle->"Hyperlink"],
  ButtonBox["The functions in the package (HelpBrowser entries)",
    ButtonData:>"HelpBrowser",
    ButtonStyle->"Hyperlink"]
}], "Text",
  CellTags->"CSSSave`"],

Cell[CellGroupData[{

Cell["General", "Section 1",
  CellTags->{"General", "CSSSave`"}],

Cell[TextData[{
  "The CSSSave` package extends the HTML export function of ",
  StyleBox[ButtonBox["Mathematica",
    ButtonData:>{
      URL[ "http://www.mathematica.com/"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  " 4 With this package also ",
  StyleBox["the colors",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0, 0]],
  " and other formats like frames and spagins are converted and displayed in \
a web browser. This is done by creating CSS (cascading style sheets) for use \
",
  StyleBox["with html files",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  ". When you convert a notebook to HTML (using either the menuitem or the \
HTMLSave command), this will automatically be done, and the colors will \
appear in any browser that is capable of cascading style sheet (Netscape 4 or \
Internet Explorer 3 or higher)."
}], "Text",
  CellTags->"CSSSave`"],

Cell["\<\
Furthermore some more features like a \"back\" link at the bottom of each \
child page are included (see the help browser entry for \"HTMLSave extensions\
\" on how to use and customize these), and bugs in the HTMLSave code are \
fixed.\
\>", "Text",
  CellTags->"CSSSave`"],

Cell[TextData[{
  "As an example you can take this page, which was also written in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " (using an adapted Report.nb Style sheet) and then converted to html using \
the CSSSave` package together with the HTMLSave function."
}], "Text",
  CellTags->"CSSSave`"],

Cell["\<\
\[NonBreakingSpace]
I have to admit, the package is not yet perfect, but normally it does a \
pretty good job. However, if you used some smart ways to create a special \
effect, be prepared that it will be lost on your html page. Still, I think, \
my package is a big improvement compared to HTMLSave alone (which converts \
only with preset styles).\
\>", "Commentary",
  CellTags->"CSSSave`"],

Cell[CellGroupData[{

Cell["Examples of converted notebooks", "Subsubsection",
  CellTags->"CSSSave`"],

Cell[TextData[{
  "Some more examples of the StyleSheets that are distributed together with \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can be found at ",
  ButtonBox["examples.html",
    ButtonData:>{
      URL[ "examples.html"], None},
    ButtonStyle->"Hyperlink"],
  ". \nA larger notebook is my software project about ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " in formal methods: ",
  ButtonBox["..\\\\VDMSL\\\\index.html",
    ButtonData:>{
      URL[ "..\\VDMSL\\index.html"], None},
    ButtonStyle->"Hyperlink"]
}], "Text",
  CellTags->"CSSSave`"]
}, Open  ]],

Cell[CellGroupData[{

Cell["System Requirements", "Subsubsection",
  CellTags->"CSSSave`"],

Cell["\<\
You need at least Mathematica Version 4 to work with that package. \
\>", "Text",
  CellTags->"CSSSave`"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["License and forbidden uses", "Section 1",
  CellTags->{"License and forbidden uses", "CSSSave`"}],

Cell["\<\
This version is free only for private, strictly noncommercial purposes. In \
exchange for this package being free, I expect to get feedback from the \
people that use this package.\
\>", "Text",
  CellTags->{"CSSSave`", "License and forbidden uses"}],

Cell[TextData[{
  "This package must not be used for any commercial purpose, including the \
conversion of a commercial page or using the converted style sheet in a \
commercial page. I think it is only fair that if you want to make money using \
my product (or to use it to create something that you want to make money \
with), I want my share of it, too, because writing this package needed quite \
a lot of time, passion and resources. \nIf you want to use this package for \
any commercial purpose, contact the author, ",
  ButtonBox["Reinhold Kainhofer",
    ButtonData:>{
      URL[ "mailto:reinhold@wolfram.com"], None},
    ButtonStyle->"Hyperlink"],
  ", to get a commercial license."
}], "Text",
  CellTags->{"CSSSave`", "License and forbidden uses"}],

Cell["\<\
Although this version is free for private use, this does not mean that the \
package will be free in the future, too. \
\>", "Commentary",
  CellTags->{"CSSSave`", "License and forbidden uses"}],

Cell["\<\
Furthermore, you have to use this package at your own risk. The author cannot \
take responsibility for any damage, harm or data loss that is caused by using \
this package.\
\>", "Text",
  CellTags->{"CSSSave`", "License and forbidden uses"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Downloading", "Section 1",
  CellTags->{"CSSSave`", "Downloading"}],

Cell["\<\
You can download the package, including some short documentation, here:\
\>", "Text",
  CellTags->{"CSSSave`", "Downloading"}],

Cell[TextData[{
  "Windows Winzip-Archive (32 kB): ",
  ButtonBox["CSSSave.zip",
    ButtonData:>{
      URL[ "CSSSave.zip"], None},
    ButtonStyle->"Hyperlink"]
}], "Text",
  CellTags->{"CSSSave`", "Downloading"}],

Cell[TextData[{
  "Please note that this package was written and tested only under Windows 95 \
and 98 (it should work under Linux and Mac as well, but I cannot guarantee \
that), using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " version 4 for Windows. This package does NOT work with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " version 3.x.x or 2.x. \nDownload this package only, if you have read the \
\"License and forbidden uses\" section above and agree with it!!!"
}], "Text",
  CellTags->{"CSSSave`", "Downloading"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Installing and Using the package", "Section 1",
  CellTags->{"Installing and Using the package", "CSSSave`"}],

Cell[TextData[{
  "Open the notebook install.nb and simply follow the instructions. It will \
copy the package into the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " AddOns directory (e.g. $TopDirectory/AddOns/Applications/CSSSave). The \
CSSSave.m file ist encoded, so don't worry if it's contents are something \
like (*!1N!*)mcm j<mi2..........\n"
}], "Text",
  CellTags->{"CSSSave`", "Installing and Using the package"}],

Cell["You can now load the package by a simple", "Text",
  CellTags->{"CSSSave`", "Installing and Using the package"}],

Cell[BoxData[
    \(<< CSSSave`\)], "Input",
  CellTags->{"CSSSave`", "Installing and Using the package"}],

Cell["\<\
That's it. When you now convert any notebook to HTML (using the menuitem in \
the File - Save as special), an additional file named the same as the html \
file, only with the extension .css will be created that holds information \
about colors and other layout information. The browser will also load this \
css file and show the html page according to the information given in the \
StyleSheet. \
\>", "Text",
  CellTags->{"CSSSave`", "Installing and Using the package"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Known Bugs / Limitations / Flaws", "Section 1",
  CellTags->{"Known Bugs / Limitations / Flaws", "CSSSave`", "CSSSave` bugs"}],

Cell[CellGroupData[{

Cell["Bugs", "Subsection",
  CellTags->{"CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],

Cell[TextData[{
  "Cells with a ButtonBox inside won't convert Margins, CellDingBat or Frame \
set at cell level (see the cell with ",
  StyleBox["NOTE:",
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " below. It should have a left frame of 2 pixel and a top frame of 1px)"
}], "Text",
  CellDingbat->"\[GrayCircle]",
  CellTags->{"CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],

Cell["\<\
The background of a Table (GridBox) is only applied to its contents in the \
html file, not to the whole <TABLE>...</TABLE>\
\>", "Text",
  CellDingbat->"\[GrayCircle]",
  CellTags->{"CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Suggestions / minor bugs which are not important", "Subsection",
  CellTags->{"CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],

Cell["\<\
If a LineSpacing is given in the StyleSheet, the spacing is too narrow in the \
browser.\
\>", "Text",
  CellDingbat->"\[GrayCircle]",
  CellTags->{"CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],

Cell["\<\
(Windows)Pathes written in Output show up with double backslashes:\
\>", "Text",
  CellDingbat->"\[GrayCircle]",
  CellTags->{"CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],

Cell[BoxData[
    \("C:\\Programme\\Mathematica\\4.0\\AddOns\\Applications\\CSSSave\\\
Examples\\test4\\default.css"\)], "Print",
  CellTags->{"CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],

Cell[TextData[{
  "The Magnification option might be translated as ",
  StyleBox["<span style=\"font-size: x%;\">...</span>", "Input"]
}], "Text",
  CellDingbat->"\[GrayCircle]",
  CellTags->{"CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],

Cell["\<\
Make the contents of the first cell with \"Title\" style the Title of the \
html page. (This needs to be done by HTMLSave).\
\>", "Text",
  CellDingbat->"\[GrayCircle]",
  CellTags->{"CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],

Cell["\<\
The CellFrameLabel and CellDingbat could be written out like normal text \
before and after the contents of the cell.\
\>", "Text",
  CellDingbat->"\[GrayCircle]",
  CellTags->{"CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],

Cell["\<\
Output in TableForm ignores the indentation (because a TableForm is \
translated into a <TABLE>, so the settings for the cell don't take effect.)\
\>", "Text",
  CellDingbat->"\[GrayCircle]",
  CellTags->{"CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Issues which can or will not be fixed", "Subsection",
  CellTags->{"CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],

Cell[TextData[{
  StyleBox["NOTE:",
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " Although this package also fixes some bugs in the HTMLSave code, I do not \
use the HTMLSave code. Rather I just ",
  ButtonBox["patch",
    ButtonData:>"patch",
    ButtonStyle->"Hyperlink"],
  " the functions which need a change. So, when a new version of the HTMLSave \
package is released, you don't need any new version of the CSSSave` package. \
Just use this version...\n However, this has the drawback that I am not able \
to fix all the bugs inside HTMLSave. "
}], "Text",
  CellFrame->{{2, 0}, {0, 0.25}},
  CellTags->{"CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],

Cell["\<\
Under Netscape the spacing is much larger than in Internet Explorer (this \
cannot and will never be fixed)\
\>", "Text",
  CellDingbat->"\[GrayCircle]",
  CellTags->{"CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],

Cell["\<\
Due to the character of the hypertext markup language (HTML), blank lines \
will not appear in the browser, except they are explicitly forced by a \
esc-nbs-esc (non-breaking-space) in the notebook.\
\>", "Text",
  CellDingbat->"\[GrayCircle]",
  CellTags->{"CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],

Cell["\<\
If Paragraphindent is set to a negative value, it is treated like 0, because \
otherwise the background in the browser would not be drawn correctly.\
\>", "Text",
  CellDingbat->"\[GrayCircle]",
  CellTags->{"CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],

Cell[CellGroupData[{

Cell["Bugs from HTMLSave", "Subsubsection",
  CellTags->{"CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],

Cell[TextData[{
  "If you use an external style sheet that is in the same directory as the \
notebook, and not in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s style sheet directory, HTMLSave will not find it and complain. This is \
a bug in HTMLSave."
}], "Text",
  CellDingbat->"\[GrayCircle]",
  CellMargins->{{90, Inherited}, {Inherited, Inherited}},
  CellTags->{"CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],

Cell["\<\
Special Characters like the \\DoubleStruckR, \\AliasDelimiter,  etc. are not \
converted right (actually, garbage is written out, because the Unicode \
character is split up into two characters, one having a character code of the \
lower, the other the code of the higher part of the original unicode \
character code). This is not CSSSave's fault, but HTMLSave's.\
\>", "Text",
  CellDingbat->"\[GrayCircle]",
  CellMargins->{{90, Inherited}, {Inherited, Inherited}},
  CellTags->{"CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],

Cell[TextData[{
  "Sometimes automatically numbered sections etc. are not numbered correctly \
in the html page. Just convert the file again (without restarting ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "), and everything will work."
}], "Text",
  CellDingbat->"\[GrayCircle]",
  CellMargins->{{90, Inherited}, {Inherited, Inherited}},
  CellTags->{"CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],

Cell["\<\
Input and Output lines will only have a line break where an explicit \
linebreak (\\n or \\\[VeryThinSpace][IndentingNewLine] was entered, resulting \
in very long lines(I should really try to fix this myself, however, I have \
not yet figured out the real problem)\
\>", "Text",
  CellDingbat->"\[GrayCircle]",
  CellMargins->{{90, Inherited}, {Inherited, Inherited}},
  CellTags->{"CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],

Cell["\<\
If there are hyperlinks in the notebook referring to other parts of the \
notebook that go into other HTML files, the resulting HTML hyperlinks don't \
work: they refer to the file they are in, not the file the target is in.\
\>", "Text",
  CellDingbat->"\[GrayCircle]",
  CellMargins->{{90, Inherited}, {Inherited, Inherited}},
  CellTags->{"CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],

Cell["\[NonBreakingSpace]", "Text",
  CellTags->{"CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "And whatever you report to ",
  ButtonBox["reinhold@wolfram.com",
    ButtonData:>{
      URL[ "mailto:reinhold@wolfram.com"], None},
    ButtonStyle->"Hyperlink"],
  "..."
}], "Subsection",
  CellTags->{"CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}]
}, Closed]],

Cell[CellGroupData[{

Cell["History", "Section 1",
  CellTags->{"History", "CSSSave`", "CSSSave` History"}],

Cell[CellGroupData[{

Cell["Changes from 0.1 to 1.0", "Subsection",
  CellTags->{"History", "CSSSave`", "CSSSave` History"}],

Cell["Fixed the double frame in typeset boxes:", "Text",
  CellTags->{"History", "CSSSave`", "CSSSave` History"}],

Cell[BoxData[
    \(asdfsafd\_babsasdf\)], "Input",
  CellTags->{"History", "CSSSave`", "CSSSave` History"}],

Cell["\<\
Giving only a directory now correctly creates the stylesheet as default.css \
in that directory\
\>", "Text",
  CellTags->{"History", "CSSSave`", "CSSSave` History"}],

Cell[TextData[{
  "The color of the border in the browser is now the same color as the \
CellFrame in ",
  StyleBox["Mathematica.",
    FontSlant->"Italic"]
}], "Text",
  CellTags->{"History", "CSSSave`", "CSSSave` History"}],

Cell["\<\
Included the CellDingbat, CellFrame, CellMargins options for a cell in the \
notebook into the block level HTML tag, so it no longer messes up spacing and \
indentation.\
\>", "Text",
  CellTags->{"History", "CSSSave`", "CSSSave` History"}],

Cell["\<\
Closed sections with a frame, CellDingbat etc. set at the cell level now work \
as hyperlinks. (They did not work under Netscape because HTMLSave wrote out \
something like <a href=...><h1>....</h1></a>, while it should have been \
<h1><a href=...>....</a></h1>).\
\>", "Text",
  CellTags->{"History", "CSSSave`", "CSSSave` History"}],

Cell["\<\
Sometimes an \\\[VeryThinSpace][IndentingNewLine] was converted to \
&IndentingNewLine; . Fixed this to a line break.\
\>", "Text",
  CellTags->{"History", "CSSSave`", "CSSSave` History"}],

Cell[TextData[{
  "In Netscape a block level attribute (like border, background etc.) in the \
css style sheet caused an inline code like StyleBox[..., \"Input\"] to start \
a new paragraph. E.g. the following text is in input style and should be in \
the same line as this text. ",
  StyleBox["This is in Input and should NOT start a new paragraph (however, \
in Netscape it did not).", "Input"],
  " This is fixed now, as I made a difference between classes applied to \
blocks and classes that are used inline. This also solved some other \
formatting problems."
}], "Text",
  CellTags->{"History", "CSSSave`", "CSSSave` History"}],

Cell[TextData[{
  "Added a navigation bar (at this time only a link to the main page) at the \
bottom with a link to jump back to the main page. (Maybe also back / forward \
buttons? This however, is not possible with the current structure of \
HTMLSave.) This feature can be turned off by the option ",
  StyleBox["MainPageLinks -> False", "Input"],
  " for HTMLSave. The text of the link can be controlled by the option ",
  StyleBox["MainPageLinkText->{\"text before link\", \"link text\", \"text \
after link\"}", "Input"],
  ". This text can also include HTML tags."
}], "Text",
  CellTags->{"History", "CSSSave`", "CSSSave` History"}],

Cell[TextData[{
  "Added an additional option \"GroupLinkType\" which controls how the link \
to a closed subgroup is shown. The default is \"Triangle\", which shows a \
small triangle like in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". Click on it, and the cellgroup will be displayed. Any other setting will \
result in the usual behaviour (the whole contents of the first cell of the \
group is a hyperlink to the group's contents)."
}], "Text",
  CellTags->{"History", "CSSSave`", "CSSSave` History"}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["The functions in the package (HelpBrowser entries)", "Section 1",
  CellTags->{"HelpBrowser", "CSSSave`"}],

Cell[CellGroupData[{

Cell[TextData[{
  "Internally a function CSSSave is defined that converts the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " style sheet to a Cascading style sheet. If you only need to create a css \
file from a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Style sheet, this is the function you need. It has the same syntax as \
HTMLSave:"
}], "Text",
  ShowGroupOpenCloseIcon->True,
  CellGroupingRules->{"SectionGrouping", 60},
  FontWeight->"Bold",
  CellTags->{"HelpBrowser", "CSSSave`"}],

Cell["CSSSave", "ObjectName",
  CellTags->{"CSSSave", "CSSSave`"}],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  StyleBox["CSSSave[\"", "MR"],
  StyleBox["file", "TI"],
  StyleBox[".css\"]", "MR"],
  " saves an CSS version of the style sheet used or defined in the currently \
selected notebook in the front end. \n\[FilledSmallSquare] ",
  StyleBox["CSSSave[\"", "MR"],
  StyleBox["file", "TI"],
  StyleBox[".css\",", "MR"],
  " ",
  StyleBox["\"", "MR"],
  StyleBox["source", "TI"],
  StyleBox[".nb\"]", "MR"],
  " saves an CSS version of the styles used or defined in the notebook from \
the file ",
  StyleBox["source", "TI"],
  StyleBox[".nb", "MR"],
  ". \n\[FilledSmallSquare] ",
  StyleBox["CSSSave[\"", "MR"],
  StyleBox["file", "TI"],
  StyleBox[".css\",", "MR"],
  " ",
  StyleBox["notebook", "TI"],
  StyleBox["]", "MR"],
  " saves an CSS version of the styles corresponding to the specified \
notebook object. "
}], "Usage",
  CellTags->{"CSSSave", "CSSSave`"}],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  StyleBox["CSSSave", "MR"],
  " has the following options:"
}], "Notes",
  CellTags->{"CSSSave", "CSSSave`"}],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              FormBox[
                StyleBox["ConversionStyleEnvironment",
                  ShowSpecialCharacters->True,
                  ShowStringCharacters->True,
                  NumberMarks->True],
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox[
                StyleBox["\"\<Working\>\"",
                  ShowSpecialCharacters->True,
                  ShowStringCharacters->True,
                  NumberMarks->True],
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox[
                RowBox[{
                  StyleBox["Which",
                    SingleLetterItalics->False], " ", 
                  StyleBox["environment",
                    SingleLetterItalics->False], " ", 
                  StyleBox["from",
                    SingleLetterItalics->False], " ", 
                  StyleBox["the",
                    SingleLetterItalics->False], " ", 
                  StyleBox["style",
                    SingleLetterItalics->False], " ", 
                  StyleBox["sheet",
                    SingleLetterItalics->False], " ", 
                  StyleBox["should",
                    SingleLetterItalics->False], " ", 
                  StyleBox["be",
                    SingleLetterItalics->False], " ", 
                  StyleBox["used",
                    SingleLetterItalics->False]}],
                "TextForm"],
              "Text",
              ShowStringCharacters->True]},
          {
            StyleBox[
              FormBox[
                StyleBox["CSSVersion",
                  ShowSpecialCharacters->True,
                  ShowStringCharacters->True,
                  NumberMarks->True],
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox[
                StyleBox["\"\<CSS1\>\"",
                  ShowSpecialCharacters->True,
                  ShowStringCharacters->True,
                  NumberMarks->True],
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox[
                RowBox[{
                  StyleBox["Version",
                    SingleLetterItalics->False], " ", 
                  StyleBox["of",
                    SingleLetterItalics->False], " ", 
                  StyleBox["the",
                    SingleLetterItalics->False], " ", 
                  StyleBox["CSS",
                    SingleLetterItalics->False], " ", 
                  StyleBox["definition",
                    SingleLetterItalics->False], 
                  " ", \(("\<CSS1\>" \(\(,\)\(\ \)\) "\<CSS2\>" \(\(,\)\(\ \)\
\) "\<NN4\>"\ or\ "\<IE4\>")\)}],
                "TextForm"],
              "Text",
              ShowStringCharacters->True]},
          {
            StyleBox[
              FormBox[
                StyleBox["ReturnSSData",
                  ShowSpecialCharacters->True,
                  ShowStringCharacters->True,
                  NumberMarks->True],
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox[
                StyleBox["False",
                  ShowSpecialCharacters->True,
                  ShowStringCharacters->True,
                  NumberMarks->True],
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox[
                RowBox[{
                  StyleBox["used",
                    SingleLetterItalics->False], " ", 
                  StyleBox["internally",
                    SingleLetterItalics->False], " ", 
                  StyleBox["by",
                    SingleLetterItalics->False], " ", 
                  StyleBox["HTMLSave",
                    SingleLetterItalics->False]}],
                "TextForm"],
              "Text"]},
          {
            StyleBox[
              FormBox[
                StyleBox["WriteSSData",
                  ShowSpecialCharacters->True,
                  ShowStringCharacters->True,
                  NumberMarks->True],
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox[
                StyleBox["False",
                  ShowSpecialCharacters->True,
                  ShowStringCharacters->True,
                  NumberMarks->True],
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["\<\"not implemented yet \"\>",
                "TextForm"],
              "Text"]}
          }], NotebookDefault]], "DefinitionBox3Col",
  GridBoxOptions->{ColumnWidths->{0.27, 0.1, 0.4}},
  CellTags->{"CSSSave", "CSSSave`"}],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  StyleBox["CSSSave", "MR"],
  " is normally not called directly but internally by HTMLSave. \n\
\[FilledSmallSquare] See also: ",
  ButtonBox["HTMLSave",
    ButtonStyle->"RefGuideLink"],
  ", ",
  ButtonBox["TeXSave",
    ButtonStyle->"RefGuideLink"],
  ", ",
  ButtonBox["Display",
    ButtonStyle->"RefGuideLink"],
  ", ",
  ButtonBox["HTMLSave extensions",
    ButtonStyle->"RefGuideLink"]
}], "Notes",
  CellTags->{"CSSSave", "CSSSave`"}],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->{"CSSSave", "CSSSave`"}],

Cell["\<\
Here is how to save this notebook as a HTML file that uses a cascading style \
sheet (note that the only difference to before is that you need to load the \
CSSSave` package):\
\>", "ExampleText",
  CellTags->{"CSSSave", "CSSSave`"}],

Cell[BoxData[
    \(<< CSSSave`\)], "Input",
  CellTags->{"CSSSave", "CSSSave`"}],

Cell[BoxData[
    \(FrontEnd`DoHTMLSave[]\)], "Input",
  CellTags->{"CSSSave", "CSSSave`"}],

Cell["\<\
Here is how to save only the styles defined in this notebook as a .CSS \
file:\
\>", "ExampleText",
  CellTags->{"CSSSave", "CSSSave`"}],

Cell[BoxData[
    \(CSSSave[]\)], "Input",
  CellTags->{"CSSSave", "CSSSave`"}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Also, the HTMLSave function was extended by 4 Options:", "Text",
  ShowGroupOpenCloseIcon->True,
  CellGroupingRules->{"SectionGrouping", 60},
  FontWeight->"Bold",
  CellTags->"CSSSave`"],

Cell["HTMLSave options extensions by CSSSave`", "ObjectName",
  CellTags->{"HTMLSave extensions", "CSSSave`"}],

Cell["As a reminder, the syntax for HTMLSave:", "Notes",
  CellTags->{"HTMLSave extensions", "CSSSave`"}],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  StyleBox["HTMLSave[\"", "MR"],
  StyleBox["file", "TI"],
  StyleBox[".html\"]", "MR"],
  " saves an HTML version of the currently selected notebook in the front \
end. \n\[FilledSmallSquare] ",
  StyleBox["HTMLSave[\"", "MR"],
  StyleBox["file", "TI"],
  StyleBox[".html\",", "MR"],
  " ",
  StyleBox["\"", "MR"],
  StyleBox["source", "TI"],
  StyleBox[".nb\"]", "MR"],
  " saves an HTML version of the notebook from the file ",
  StyleBox["source", "TI"],
  StyleBox[".nb", "MR"],
  ". \n\[FilledSmallSquare] ",
  StyleBox["HTMLSave[\"", "MR"],
  StyleBox["file", "TI"],
  StyleBox[".html\",", "MR"],
  " ",
  StyleBox["notebook", "TI"],
  StyleBox["]", "MR"],
  " saves an HTML version of the notebook corresponding to the specified \
notebook object. "
}], "Usage",
  CellTags->{"HTMLSave extensions", "CSSSave`"}],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  StyleBox["HTMLSave", "MR"],
  " was extended by the following two options, which are added as soon as you \
load the CSSSave` package."
}], "Notes",
  CellTags->{"HTMLSave extensions", "CSSSave`"}],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              FormBox[
                StyleBox["CSSFile",
                  ShowSpecialCharacters->True,
                  ShowStringCharacters->True,
                  NumberMarks->True],
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["None",
                "StandardForm"],
              "Text"], 
            StyleBox[
              
              FormBox[\(Name\ of\ the\ CSSFile\ which\ is\ linked\ to\ the\ \
HTML\ file . \ 
                    If\ you\ already\ have\ one\ Cascading\ Style\ sheet\ \
that\ you\ wand\ to\ use\ with\ all\ your\ converted\ notebooks, \ 
                just\ give\ the\ \(\(filename\)\(.\)\)\),
                "TextForm"],
              "Text",
              ShowStringCharacters->True]},
          {
            StyleBox[
              FormBox[
                StyleBox["MainPageLinks",
                  ShowSpecialCharacters->True,
                  ShowStringCharacters->True,
                  NumberMarks->True],
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["True",
                "StandardForm"],
              "Text"], 
            StyleBox[
              
              FormBox[\(Determines\ wheter\ subfiles\ \((e . g . \ 
                        a\ closed\ group)\)\ contain\ a\ link\ at\ the\ \
bottom\ that\ points\ to\ the\ main\ page\ \((the\ page\ that\ you\ initially\
\ converted)\) . \ 
                    Very\ useful\ as\ a\ "\<Back to the main page\>"\ \
\(\(link\)\(.\)\)\),
                "TextForm"],
              "Text",
              ShowStringCharacters->True]},
          {
            StyleBox[
              FormBox[
                StyleBox["MainPageLinksText",
                  ShowSpecialCharacters->True,
                  ShowStringCharacters->True,
                  NumberMarks->True],
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox[
                
                StyleBox[\({"\<<hr><center>Back to the \>", \ "\<Main \
Page\>", \ "\<</center>\>"}\),
                  ShowSpecialCharacters->True,
                  ShowStringCharacters->True,
                  NumberMarks->True],
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox[
                RowBox[{
                  
                  StyleBox[\(Determines\ the\ text\ that\ is\ shown\ in\ the\ \
link\ back\ to\ the\ main\ page\ \((only\ if\ MainPageLinks -> True)\) . \ 
                        The\ list\ consists\ of\ three\ \(entries : \ 
                        The\ text\ before\ the\ link\)\),
                    SingleLetterItalics->False], 
                  StyleBox[",",
                    SingleLetterItalics->False], 
                  StyleBox[" ",
                    SingleLetterItalics->False], 
                  RowBox[{
                    StyleBox["at",
                      SingleLetterItalics->False], 
                    StyleBox[" ",
                      SingleLetterItalics->False], 
                    StyleBox["the",
                      SingleLetterItalics->False], 
                    StyleBox[" ",
                      SingleLetterItalics->False], 
                    StyleBox["link",
                      SingleLetterItalics->False], 
                    StyleBox[" ",
                      SingleLetterItalics->False], 
                    StyleBox["and",
                      SingleLetterItalics->False], 
                    StyleBox[" ",
                      SingleLetterItalics->False], 
                    StyleBox["after",
                      SingleLetterItalics->False], 
                    StyleBox[" ",
                      SingleLetterItalics->False], 
                    StyleBox["the",
                      SingleLetterItalics->False], 
                    StyleBox[" ",
                      SingleLetterItalics->False], 
                    StyleBox["link",
                      SingleLetterItalics->False], 
                    StyleBox[" ",
                      SingleLetterItalics->False], 
                    StyleBox["to",
                      SingleLetterItalics->False], 
                    StyleBox[" ",
                      SingleLetterItalics->False], 
                    StyleBox["the",
                      SingleLetterItalics->False], 
                    StyleBox[" ",
                      SingleLetterItalics->False], 
                    StyleBox["main",
                      SingleLetterItalics->False], 
                    StyleBox[" ",
                      SingleLetterItalics->False], 
                    RowBox[{
                      StyleBox["page",
                        SingleLetterItalics->False], 
                      StyleBox[".",
                        SingleLetterItalics->False], " "}]}]}],
                "TextForm"],
              "Text"]},
          {
            StyleBox[
              FormBox[
                StyleBox["GroupLinkType",
                  ShowSpecialCharacters->True,
                  ShowStringCharacters->True,
                  NumberMarks->True],
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox[
                StyleBox["\"\<Default\>\"",
                  ShowSpecialCharacters->True,
                  ShowStringCharacters->True,
                  NumberMarks->True],
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox[
                
                StyleBox[\(Determines\ how\ the\ link\ to\ closed\ groups\ \
will\ \ look\ like . \ 
                      The\ setting\ Triangle\ displays\ a\ small\ triangle\ \
at\ the\ left\ of\ the\ first\ cell, \ 
                  which\ is\ a\ hyperlink\ to\ the\ cell' 
                    s\ contents . \ 
                      Any\ other\ setting\ results\ in\ the\ current\ \
behaviour, \ 
                  that\ the\ whole\ contents\ of\ the\ first\ cell\ are\ a\ \
hyperlink\ to\ the\ group' s\ \(\(contens\)\(.\)\(\ \)\)\),
                  SingleLetterItalics->False],
                "TextForm"],
              "Text"]}
          }], NotebookDefault]], "DefinitionBox3Col",
  GridBoxOptions->{ColumnWidths->{0.2, 0.2, 0.4}},
  CellTags->{"HTMLSave extensions", "CSSSave`"}],

Cell["\<\
If you want to change these options, the best way to do so is to use:\
\>", "Notes",
  CellTags->{"HTMLSave extensions", "CSSSave`"}],

Cell["\<\
Unprotect[HTMLSave];
SetOptions[HTMLSave, GroupLinkType->\"Triangle\"]\
\>", "Input",
  CellTags->{"HTMLSave extensions", "CSSSave`"}],

Cell[TextData[{
  "\[FilledSmallSquare] See also: ",
  ButtonBox["HTMLSave",
    ButtonStyle->"RefGuideLink"],
  ", ",
  ButtonBox["CSSSave",
    ButtonStyle->"AddOnsLink"],
  ". "
}], "Notes",
  CellTags->{"HTMLSave extensions", "CSSSave`"}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Patching existing functions", "Section 1",
  CellTags->{"patch", "CSSSave`"}],

Cell["\<\
Whenever I have to correct a function from the HTMLSave` package, I either \
have to rewrite the whole function, but mostly, I just need to apply a few \
changes to the result that is returned by the function. In the latter case, \
one can use a construct like the following:\
\>", "Text",
  CellTags->{"patch", "CSSSave`"}],

Cell[TextData[{
  StyleBox["function[ args___ ] /;!TrueQ[UsePatchX] := Block[ \
{UsePatchQ=True,res},\n  ", "Input"],
  StyleBox["(*any custom settings for the function, e.g. changing args: *)", 
    "Commentary"],
  StyleBox["yourowncode;\n  ", "Input"],
  StyleBox["(*call to original function: *)", "Commentary"],
  StyleBox["res=function[args];\n  ", "Input"],
  StyleBox["(*change the result:*)", "Commentary"],
  StyleBox["yourowncode1;\n  res \n];", "Input"],
  " "
}], "Input",
  CellTags->{"patch", "CSSSave`"}],

Cell[TextData[{
  "The ",
  StyleBox["/;!TrueQ[UsePatchX]", "Input"],
  " and the ",
  StyleBox["Block[{UsePatchX},...]", "Input"],
  " are needed to that inside the block the old definition for the function \
is called and not our newly defined one."
}], "Text",
  CellTags->{"patch", "CSSSave`"}]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 713}},
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{728, 669},
WindowMargins->{{Automatic, 50}, {Automatic, 2}},
IndexCreationOptions->{"Format"->"Hyperlinks"},
CellLabelAutoDelete->True,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.
Make modifications to any definition using commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Color"->RGBColor[0.4, 0, 0.239994]},
    ScriptMinSize->9,
    Background->RGBColor[1, 0.960006, 0.900008]],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Color"->RGBColor[0.744411, 0.47155, 0.371542]},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowCellLabel->False,
    ImageSize->{200, 200},
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellFrame->{{0, 0}, {0, 0.25}},
    CellMargins->{{18, 10}, {0, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->6,
    CellFrameColor->GrayLevel[0],
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    LineSpacing->{0.95, 0},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->RGBColor[0.4, 0, 0.239994]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{20, 10}, {2, 20}},
    CellFrameMargins->5,
    FontColor->RGBColor[0.744411, 0.47155, 0.371542]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{18, 30}, {0, 0}},
    CellFrameMargins->4,
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{20, 30}, {2, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    ConversionRules:>{"HTML" -> {{"<BIG>", "</BIG>"}, {"<H3>", "</H3>"}}},
    PageBreakBelow->False,
    CellFrameMargins->{{0, 4}, {8, 4}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    LineSpacing->{1, 0},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{20, 10}, {2, 10}}],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{18, 30}, {0, 10}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section 1"],
    CellFrame->{{0, 0}, {0, 3}},
    CellMargins->{{18, 10}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->{{0, 4}, {8, 4}},
    CellFrameColor->RGBColor[1, 0, 0.239994],
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section 1", "Presentation"],
    CellMargins->{{20, 10}, {6, 30}},
    CellFrameMargins->5],
  
  Cell[StyleData["Section 1", "Printout"],
    CellMargins->{{18, 30}, {4, 30}},
    CellFrameMargins->4,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 0.25}},
    CellMargins->{{18, 10}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0.4, 0, 0.239994],
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{20, 10}, {0, 30}}],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{18, 30}, {0, 30}},
    CellFrameMargins->5,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{38, 30}, {2, 20}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{35, 30}, {0, 20}}],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{18, 30}, {0, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{55, 30}, {4, 10}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{31, 30}, {0, 12}}],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{18, 30}, {0, 12}},
    FontSize->10]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{55, 10}, {6, 6}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 2},
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{20, 10}, {6, 6}},
    TextAlignment->Left,
    TextJustification->0,
    LineSpacing->{1.3, 0},
    FontSize->14],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{18, 4}, {4, 4}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellMargins->{{55, 10}, {2, 6}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 2},
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["Commentary", "Presentation"],
    CellMargins->{{60, 30}, {2, 6}},
    TextJustification->1,
    LineSpacing->{1.3, 0},
    FontSize->12],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{18, 30}, {3, 0}},
    LineSpacing->{1, 3},
    FontFamily->"Times",
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->{{1, 1}, {0, 1}},
    CellMargins->{{55, 10}, {0, 0}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelPositioning->Automatic,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    FontSize->12,
    FontWeight->"Bold",
    Background->GrayLevel[0.966674]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{60, 10}, {0, 10}},
    Background->GrayLevel[0.850004]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{55, 10}, {0, 10}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->10,
    Background->GrayLevel[0.850004]]
  }, Closed]],
  
  Cell[StyleData["InlineInput"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->{{1, 1}, {1, 0}},
    CellMargins->{{55, 10}, {15, 0}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    FontSize->12,
    Background->GrayLevel[0.850004]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{60, Inherited}, {10, 0}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{55, Inherited}, {10, 0}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InputOnly"],
    CellFrame->1,
    CellMargins->{{55, 10}, {15, 0}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelPositioning->Automatic,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    FontSize->12,
    FontWeight->"Bold",
    Background->GrayLevel[0.966674]],
  
  Cell[StyleData["InputOnly", "Presentation"],
    CellMargins->{{60, Inherited}, {10, 10}}],
  
  Cell[StyleData["InputOnly", "Printout"],
    CellMargins->{{55, Inherited}, {10, 10}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellFrame->{{1, 1}, {0, 0}},
    CellDingbat->"\[LongDash]",
    CellMargins->{{55, 10}, {0, 0}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{60, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{55, Inherited}, {0, 0}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{55, 26}, {1, 6}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Left,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    Background->GrayLevel[0.700008]],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{60, Inherited}, {10, 2}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, Inherited}, {2, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellFrame->{{1, 1}, {0, 0}},
    CellMargins->{{55, 10}, {0, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    Background->GrayLevel[0.850004]],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{60, Inherited}, {0, 0}},
    ImageMargins->{{10, 10}, {10, 10}}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{55, Inherited}, {0, 0}},
    ImageSize->{0.0625, 0.0625}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontSlant->"Oblique",
    FontColor->RGBColor[0.6, 0, 0.6]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    CellMargins->{{18, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["CellLabel", "Printout"],
    CellMargins->{{0, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{20, 30}, {45, 5}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CellFrameMargins->{{0, 4}, {8, 4}},
    LineSpacing->{1, 0},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{20, 30}, {45, 10}}],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{18, 30}, {45, 5}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellFrame->False,
    CellMargins->{{18, 140}, {4, 30}},
    Hyphenation->True,
    LineSpacing->{0.9, 0},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Abstract", "Presentation"],
    CellFrame->True,
    CellMargins->{{20, 10}, {Inherited, 30}}],
  
  Cell[StyleData["Abstract", "Printout"],
    LineSpacing->{1, 2},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{55, 10}, {5, 3}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Presentation"],
    CellMargins->{{60, 65}, {6, 4}},
    FontSize->10],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{55, 55}, {5, 4}},
    LineSpacing->{1, 2},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{24, 40}, {6, 6}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 0},
    FontFamily->"Times"],
  
  Cell[StyleData["Reference", "Presentation"],
    CellMargins->{{20, 40}, {Inherited, 6}},
    TextJustification->0,
    LineSpacing->{1, 4},
    FontSize->12],
  
  Cell[StyleData["Reference", "Printout"],
    CellMargins->{{18, 4}, {4, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellFrame->{{1, 1}, {0, 0}},
    CellMargins->{{55, Inherited}, {0, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    ShowCellLabel->False,
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    Background->GrayLevel[0.850004]],
  
  Cell[StyleData["PictureGroup", "Presentation"],
    CellMargins->{{60, Inherited}, {0, 0}},
    ImageMargins->{{10, 10}, {10, 10}}],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{55, Inherited}, {0, 0}},
    ImageSize->{0.0625, 0.0625}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    CellMargins->{{60, 10}, {Inherited, 6}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{18, 4}, {4, 4}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{55, 10}, {Inherited, 0}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    TextJustification->1,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{60, 10}, {Inherited, 6}}],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{18, 4}, {4, 4}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{55, 10}, {Inherited, 0}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{60, 10}, {Inherited, 6}}],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{18, 4}, {4, 4}},
    LineSpacing->{1, 3},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{55, 85}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontFamily->"Times"],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    CellMargins->{{60, 10}, {Inherited, 6}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{18, 4}, {4, 4}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{55, 95}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}], FontWeight -> "Bold"], None}},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False,
    FontFamily->"Times"],
  
  Cell[StyleData["NumberedFigure", "Presentation"],
    CellMargins->{{60, 80}, {Inherited, 6}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    CellMargins->{{18, 80}, {4, 4}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{55, 95}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}], FontWeight -> "Bold"], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False,
    FontFamily->"Times"],
  
  Cell[StyleData["NumberedTable", "Presentation"],
    CellMargins->{{60, 80}, {Inherited, 6}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["NumberedTable", "Printout"],
    CellMargins->{{18, 80}, {4, 4}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["PageNumber"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"],
  
  Cell[StyleData["Footer"],
    TextAlignment->Center,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles of most \
cells.  If a cell's FormatType matches the name of one of the styles defined \
below, then that style is applied between the cell's style and its own \
options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an inline cell \
within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles from HelpBrowser.nb", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"]
  }, Closed]]
  }, Open  ]]
  }]
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CSSSave`"->{
    Cell[1739, 51, 57, 1, 67, "Title",
      CellTags->"CSSSave`"],
    Cell[1799, 54, 55, 1, 39, "Subtitle",
      CellTags->"CSSSave`"],
    Cell[1857, 57, 123, 3, 66, "Author",
      CellTags->"CSSSave`"],
    Cell[1983, 62, 1072, 37, 131, "Text",
      CellTags->"CSSSave`"],
    Cell[3080, 103, 65, 1, 70, "Section 1",
      CellTags->{"General", "CSSSave`"}],
    Cell[3148, 106, 930, 23, 97, "Text",
      CellTags->"CSSSave`"],
    Cell[4081, 131, 284, 6, 46, "Text",
      CellTags->"CSSSave`"],
    Cell[4368, 139, 312, 7, 46, "Text",
      CellTags->"CSSSave`"],
    Cell[4683, 148, 404, 8, 68, "Commentary",
      CellTags->"CSSSave`"],
    Cell[5112, 160, 80, 1, 31, "Subsubsection",
      CellTags->"CSSSave`"],
    Cell[5195, 163, 589, 19, 46, "Text",
      CellTags->"CSSSave`"],
    Cell[5821, 187, 68, 1, 31, "Subsubsection",
      CellTags->"CSSSave`"],
    Cell[5892, 190, 115, 3, 29, "Text",
      CellTags->"CSSSave`"],
    Cell[6056, 199, 103, 1, 70, "Section 1",
      CellTags->{"License and forbidden uses", "CSSSave`"}],
    Cell[6162, 202, 260, 5, 46, "Text",
      CellTags->{"CSSSave`", "License and forbidden uses"}],
    Cell[6425, 209, 761, 14, 97, "Text",
      CellTags->{"CSSSave`", "License and forbidden uses"}],
    Cell[7189, 225, 204, 4, 23, "Commentary",
      CellTags->{"CSSSave`", "License and forbidden uses"}],
    Cell[7396, 231, 253, 5, 46, "Text",
      CellTags->{"CSSSave`", "License and forbidden uses"}],
    Cell[7686, 241, 73, 1, 70, "Section 1",
      CellTags->{"CSSSave`", "Downloading"}],
    Cell[7762, 244, 136, 3, 29, "Text",
      CellTags->{"CSSSave`", "Downloading"}],
    Cell[7901, 249, 215, 7, 29, "Text",
      CellTags->{"CSSSave`", "Downloading"}],
    Cell[8119, 258, 553, 12, 80, "Text",
      CellTags->{"CSSSave`", "Downloading"}],
    Cell[8709, 275, 115, 1, 70, "Section 1",
      CellTags->{"Installing and Using the package", "CSSSave`"}],
    Cell[8827, 278, 437, 9, 80, "Text",
      CellTags->{"CSSSave`", "Installing and Using the package"}],
    Cell[9267, 289, 118, 1, 29, "Text",
      CellTags->{"CSSSave`", "Installing and Using the package"}],
    Cell[9388, 292, 106, 2, 35, "Input",
      CellTags->{"CSSSave`", "Installing and Using the package"}],
    Cell[9497, 296, 482, 8, 63, "Text",
      CellTags->{"CSSSave`", "Installing and Using the package"}],
    Cell[10016, 309, 132, 1, 70, "Section 1",
      CellTags->{
      "Known Bugs / Limitations / Flaws", "CSSSave`", "CSSSave` bugs"}],
    Cell[10173, 314, 105, 1, 41, "Subsection",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[10281, 317, 420, 10, 47, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[10704, 329, 258, 5, 29, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[10999, 339, 149, 1, 41, "Subsection",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[11151, 342, 223, 5, 29, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[11377, 349, 201, 4, 29, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[11581, 355, 208, 3, 40, "Print",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[11792, 360, 257, 5, 30, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[12052, 367, 258, 5, 29, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[12313, 374, 252, 5, 29, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[12568, 381, 280, 5, 46, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[12885, 391, 138, 1, 41, "Subsection",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[13026, 394, 702, 16, 89, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[13731, 412, 242, 5, 29, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[13976, 419, 333, 6, 46, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[14312, 427, 283, 5, 46, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[14620, 436, 122, 1, 31, "Subsubsection",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[14745, 439, 448, 10, 46, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[15196, 451, 557, 9, 63, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[15756, 462, 429, 9, 46, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[16188, 473, 458, 8, 46, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[16649, 483, 417, 7, 46, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[17069, 492, 114, 1, 29, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[17210, 497, 288, 8, 41, "Subsection",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[17535, 510, 85, 1, 44, "Section 1",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[17645, 515, 102, 1, 41, "Subsection",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[17750, 518, 113, 1, 29, "Text",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[17866, 521, 108, 2, 35, "Input",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[17977, 525, 176, 4, 29, "Text",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[18156, 531, 225, 6, 29, "Text",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[18384, 539, 250, 5, 46, "Text",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[18637, 546, 344, 6, 63, "Text",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[18984, 554, 198, 4, 29, "Text",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[19185, 560, 634, 11, 99, "Text",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[19822, 573, 640, 11, 99, "Text",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[20465, 586, 521, 10, 63, "Text",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[21035, 602, 112, 1, 44, "Section 1",
      CellTags->{"HelpBrowser", "CSSSave`"}],
    Cell[21172, 607, 518, 14, 63, "Text",
      CellGroupingRules->{"SectionGrouping", 60},
      CellTags->{"HelpBrowser", "CSSSave`"}],
    Cell[21693, 623, 66, 1, 31, "ObjectName",
      CellTags->{"CSSSave", "CSSSave`"}],
    Cell[21762, 626, 906, 28, 78, "Usage",
      CellTags->{"CSSSave", "CSSSave`"}],
    Cell[22671, 656, 153, 5, 25, "Notes",
      CellTags->{"CSSSave", "CSSSave`"}],
    Cell[22827, 663, 4741, 131, 102, "DefinitionBox3Col",
      CellTags->{"CSSSave", "CSSSave`"}],
    Cell[27571, 796, 487, 17, 48, "Notes",
      CellTags->{"CSSSave", "CSSSave`"}],
    Cell[28083, 817, 79, 1, 40, "ExampleSection",
      CellTags->{"CSSSave", "CSSSave`"}],
    Cell[28165, 820, 243, 5, 35, "ExampleText",
      CellTags->{"CSSSave", "CSSSave`"}],
    Cell[28411, 827, 81, 2, 35, "Input",
      CellTags->{"CSSSave", "CSSSave`"}],
    Cell[28495, 831, 91, 2, 35, "Input",
      CellTags->{"CSSSave", "CSSSave`"}],
    Cell[28589, 835, 146, 4, 35, "ExampleText",
      CellTags->{"CSSSave", "CSSSave`"}],
    Cell[28738, 841, 79, 2, 35, "Input",
      CellTags->{"CSSSave", "CSSSave`"}],
    Cell[28866, 849, 194, 4, 27, "Text",
      CellGroupingRules->{"SectionGrouping", 60},
      CellTags->"CSSSave`"],
    Cell[29063, 855, 110, 1, 31, "ObjectName",
      CellTags->{"HTMLSave extensions", "CSSSave`"}],
    Cell[29176, 858, 105, 1, 25, "Notes",
      CellTags->{"HTMLSave extensions", "CSSSave`"}],
    Cell[29284, 861, 862, 27, 78, "Usage",
      CellTags->{"HTMLSave extensions", "CSSSave`"}],
    Cell[30149, 890, 242, 6, 25, "Notes",
      CellTags->{"HTMLSave extensions", "CSSSave`"}],
    Cell[30394, 898, 6410, 164, 404, "DefinitionBox3Col",
      CellTags->{"HTMLSave extensions", "CSSSave`"}],
    Cell[36807, 1064, 143, 3, 25, "Notes",
      CellTags->{"HTMLSave extensions", "CSSSave`"}],
    Cell[36953, 1069, 144, 4, 53, "Input",
      CellTags->{"HTMLSave extensions", "CSSSave`"}],
    Cell[37100, 1075, 242, 9, 25, "Notes",
      CellTags->{"HTMLSave extensions", "CSSSave`"}],
    Cell[37391, 1090, 83, 1, 70, "Section 1",
      CellTags->{"patch", "CSSSave`"}],
    Cell[37477, 1093, 334, 6, 46, "Text",
      CellTags->{"patch", "CSSSave`"}],
    Cell[37814, 1101, 520, 12, 125, "Input",
      CellTags->{"patch", "CSSSave`"}],
    Cell[38337, 1115, 298, 8, 47, "Text",
      CellTags->{"patch", "CSSSave`"}]},
  "General"->{
    Cell[3080, 103, 65, 1, 70, "Section 1",
      CellTags->{"General", "CSSSave`"}]},
  "License and forbidden uses"->{
    Cell[6056, 199, 103, 1, 70, "Section 1",
      CellTags->{"License and forbidden uses", "CSSSave`"}],
    Cell[6162, 202, 260, 5, 46, "Text",
      CellTags->{"CSSSave`", "License and forbidden uses"}],
    Cell[6425, 209, 761, 14, 97, "Text",
      CellTags->{"CSSSave`", "License and forbidden uses"}],
    Cell[7189, 225, 204, 4, 23, "Commentary",
      CellTags->{"CSSSave`", "License and forbidden uses"}],
    Cell[7396, 231, 253, 5, 46, "Text",
      CellTags->{"CSSSave`", "License and forbidden uses"}]},
  "Downloading"->{
    Cell[7686, 241, 73, 1, 70, "Section 1",
      CellTags->{"CSSSave`", "Downloading"}],
    Cell[7762, 244, 136, 3, 29, "Text",
      CellTags->{"CSSSave`", "Downloading"}],
    Cell[7901, 249, 215, 7, 29, "Text",
      CellTags->{"CSSSave`", "Downloading"}],
    Cell[8119, 258, 553, 12, 80, "Text",
      CellTags->{"CSSSave`", "Downloading"}]},
  "Installing and Using the package"->{
    Cell[8709, 275, 115, 1, 70, "Section 1",
      CellTags->{"Installing and Using the package", "CSSSave`"}],
    Cell[8827, 278, 437, 9, 80, "Text",
      CellTags->{"CSSSave`", "Installing and Using the package"}],
    Cell[9267, 289, 118, 1, 29, "Text",
      CellTags->{"CSSSave`", "Installing and Using the package"}],
    Cell[9388, 292, 106, 2, 35, "Input",
      CellTags->{"CSSSave`", "Installing and Using the package"}],
    Cell[9497, 296, 482, 8, 63, "Text",
      CellTags->{"CSSSave`", "Installing and Using the package"}]},
  "Known Bugs / Limitations / Flaws"->{
    Cell[10016, 309, 132, 1, 70, "Section 1",
      CellTags->{
      "Known Bugs / Limitations / Flaws", "CSSSave`", "CSSSave` bugs"}],
    Cell[10173, 314, 105, 1, 41, "Subsection",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[10281, 317, 420, 10, 47, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[10704, 329, 258, 5, 29, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[10999, 339, 149, 1, 41, "Subsection",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[11151, 342, 223, 5, 29, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[11377, 349, 201, 4, 29, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[11581, 355, 208, 3, 40, "Print",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[11792, 360, 257, 5, 30, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[12052, 367, 258, 5, 29, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[12313, 374, 252, 5, 29, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[12568, 381, 280, 5, 46, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[12885, 391, 138, 1, 41, "Subsection",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[13026, 394, 702, 16, 89, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[13731, 412, 242, 5, 29, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[13976, 419, 333, 6, 46, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[14312, 427, 283, 5, 46, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[14620, 436, 122, 1, 31, "Subsubsection",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[14745, 439, 448, 10, 46, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[15196, 451, 557, 9, 63, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[15756, 462, 429, 9, 46, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[16188, 473, 458, 8, 46, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[16649, 483, 417, 7, 46, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[17069, 492, 114, 1, 29, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[17210, 497, 288, 8, 41, "Subsection",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}]},
  "CSSSave` bugs"->{
    Cell[10016, 309, 132, 1, 70, "Section 1",
      CellTags->{
      "Known Bugs / Limitations / Flaws", "CSSSave`", "CSSSave` bugs"}],
    Cell[10173, 314, 105, 1, 41, "Subsection",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[10281, 317, 420, 10, 47, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[10704, 329, 258, 5, 29, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[10999, 339, 149, 1, 41, "Subsection",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[11151, 342, 223, 5, 29, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[11377, 349, 201, 4, 29, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[11581, 355, 208, 3, 40, "Print",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[11792, 360, 257, 5, 30, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[12052, 367, 258, 5, 29, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[12313, 374, 252, 5, 29, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[12568, 381, 280, 5, 46, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[12885, 391, 138, 1, 41, "Subsection",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[13026, 394, 702, 16, 89, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[13731, 412, 242, 5, 29, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[13976, 419, 333, 6, 46, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[14312, 427, 283, 5, 46, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[14620, 436, 122, 1, 31, "Subsubsection",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[14745, 439, 448, 10, 46, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[15196, 451, 557, 9, 63, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[15756, 462, 429, 9, 46, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[16188, 473, 458, 8, 46, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[16649, 483, 417, 7, 46, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[17069, 492, 114, 1, 29, "Text",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
    Cell[17210, 497, 288, 8, 41, "Subsection",
      CellTags->{
      "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}]},
  "History"->{
    Cell[17535, 510, 85, 1, 44, "Section 1",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[17645, 515, 102, 1, 41, "Subsection",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[17750, 518, 113, 1, 29, "Text",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[17866, 521, 108, 2, 35, "Input",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[17977, 525, 176, 4, 29, "Text",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[18156, 531, 225, 6, 29, "Text",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[18384, 539, 250, 5, 46, "Text",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[18637, 546, 344, 6, 63, "Text",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[18984, 554, 198, 4, 29, "Text",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[19185, 560, 634, 11, 99, "Text",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[19822, 573, 640, 11, 99, "Text",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[20465, 586, 521, 10, 63, "Text",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}]},
  "CSSSave` History"->{
    Cell[17535, 510, 85, 1, 44, "Section 1",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[17645, 515, 102, 1, 41, "Subsection",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[17750, 518, 113, 1, 29, "Text",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[17866, 521, 108, 2, 35, "Input",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[17977, 525, 176, 4, 29, "Text",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[18156, 531, 225, 6, 29, "Text",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[18384, 539, 250, 5, 46, "Text",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[18637, 546, 344, 6, 63, "Text",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[18984, 554, 198, 4, 29, "Text",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[19185, 560, 634, 11, 99, "Text",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[19822, 573, 640, 11, 99, "Text",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}],
    Cell[20465, 586, 521, 10, 63, "Text",
      CellTags->{"History", "CSSSave`", "CSSSave` History"}]},
  "HelpBrowser"->{
    Cell[21035, 602, 112, 1, 44, "Section 1",
      CellTags->{"HelpBrowser", "CSSSave`"}],
    Cell[21172, 607, 518, 14, 63, "Text",
      CellGroupingRules->{"SectionGrouping", 60},
      CellTags->{"HelpBrowser", "CSSSave`"}]},
  "CSSSave"->{
    Cell[21693, 623, 66, 1, 31, "ObjectName",
      CellTags->{"CSSSave", "CSSSave`"}],
    Cell[21762, 626, 906, 28, 78, "Usage",
      CellTags->{"CSSSave", "CSSSave`"}],
    Cell[22671, 656, 153, 5, 25, "Notes",
      CellTags->{"CSSSave", "CSSSave`"}],
    Cell[22827, 663, 4741, 131, 102, "DefinitionBox3Col",
      CellTags->{"CSSSave", "CSSSave`"}],
    Cell[27571, 796, 487, 17, 48, "Notes",
      CellTags->{"CSSSave", "CSSSave`"}],
    Cell[28083, 817, 79, 1, 40, "ExampleSection",
      CellTags->{"CSSSave", "CSSSave`"}],
    Cell[28165, 820, 243, 5, 35, "ExampleText",
      CellTags->{"CSSSave", "CSSSave`"}],
    Cell[28411, 827, 81, 2, 35, "Input",
      CellTags->{"CSSSave", "CSSSave`"}],
    Cell[28495, 831, 91, 2, 35, "Input",
      CellTags->{"CSSSave", "CSSSave`"}],
    Cell[28589, 835, 146, 4, 35, "ExampleText",
      CellTags->{"CSSSave", "CSSSave`"}],
    Cell[28738, 841, 79, 2, 35, "Input",
      CellTags->{"CSSSave", "CSSSave`"}]},
  "HTMLSave extensions"->{
    Cell[29063, 855, 110, 1, 31, "ObjectName",
      CellTags->{"HTMLSave extensions", "CSSSave`"}],
    Cell[29176, 858, 105, 1, 25, "Notes",
      CellTags->{"HTMLSave extensions", "CSSSave`"}],
    Cell[29284, 861, 862, 27, 78, "Usage",
      CellTags->{"HTMLSave extensions", "CSSSave`"}],
    Cell[30149, 890, 242, 6, 25, "Notes",
      CellTags->{"HTMLSave extensions", "CSSSave`"}],
    Cell[30394, 898, 6410, 164, 404, "DefinitionBox3Col",
      CellTags->{"HTMLSave extensions", "CSSSave`"}],
    Cell[36807, 1064, 143, 3, 25, "Notes",
      CellTags->{"HTMLSave extensions", "CSSSave`"}],
    Cell[36953, 1069, 144, 4, 53, "Input",
      CellTags->{"HTMLSave extensions", "CSSSave`"}],
    Cell[37100, 1075, 242, 9, 25, "Notes",
      CellTags->{"HTMLSave extensions", "CSSSave`"}]},
  "patch"->{
    Cell[37391, 1090, 83, 1, 70, "Section 1",
      CellTags->{"patch", "CSSSave`"}],
    Cell[37477, 1093, 334, 6, 46, "Text",
      CellTags->{"patch", "CSSSave`"}],
    Cell[37814, 1101, 520, 12, 125, "Input",
      CellTags->{"patch", "CSSSave`"}],
    Cell[38337, 1115, 298, 8, 47, "Text",
      CellTags->{"patch", "CSSSave`"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CSSSave`", 76297, 2395},
  {"General", 85695, 2603},
  {"License and forbidden uses", 85816, 2606},
  {"Downloading", 86353, 2617},
  {"Installing and Using the package", 86743, 2626},
  {"Known Bugs / Limitations / Flaws", 87325, 2637},
  {"CSSSave` bugs", 90689, 2713},
  {"History", 94047, 2789},
  {"CSSSave` History", 95322, 2814},
  {"HelpBrowser", 96592, 2839},
  {"CSSSave", 96838, 2845},
  {"HTMLSave extensions", 97829, 2868},
  {"patch", 98636, 2885}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 57, 1, 67, "Title",
  CellTags->"CSSSave`"],
Cell[1799, 54, 55, 1, 39, "Subtitle",
  CellTags->"CSSSave`"],
Cell[1857, 57, 123, 3, 66, "Author",
  CellTags->"CSSSave`"],
Cell[1983, 62, 1072, 37, 131, "Text",
  CellTags->"CSSSave`"],

Cell[CellGroupData[{
Cell[3080, 103, 65, 1, 70, "Section 1",
  CellTags->{"General", "CSSSave`"}],
Cell[3148, 106, 930, 23, 97, "Text",
  CellTags->"CSSSave`"],
Cell[4081, 131, 284, 6, 46, "Text",
  CellTags->"CSSSave`"],
Cell[4368, 139, 312, 7, 46, "Text",
  CellTags->"CSSSave`"],
Cell[4683, 148, 404, 8, 68, "Commentary",
  CellTags->"CSSSave`"],

Cell[CellGroupData[{
Cell[5112, 160, 80, 1, 31, "Subsubsection",
  CellTags->"CSSSave`"],
Cell[5195, 163, 589, 19, 46, "Text",
  CellTags->"CSSSave`"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5821, 187, 68, 1, 31, "Subsubsection",
  CellTags->"CSSSave`"],
Cell[5892, 190, 115, 3, 29, "Text",
  CellTags->"CSSSave`"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6056, 199, 103, 1, 70, "Section 1",
  CellTags->{"License and forbidden uses", "CSSSave`"}],
Cell[6162, 202, 260, 5, 46, "Text",
  CellTags->{"CSSSave`", "License and forbidden uses"}],
Cell[6425, 209, 761, 14, 97, "Text",
  CellTags->{"CSSSave`", "License and forbidden uses"}],
Cell[7189, 225, 204, 4, 23, "Commentary",
  CellTags->{"CSSSave`", "License and forbidden uses"}],
Cell[7396, 231, 253, 5, 46, "Text",
  CellTags->{"CSSSave`", "License and forbidden uses"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[7686, 241, 73, 1, 70, "Section 1",
  CellTags->{"CSSSave`", "Downloading"}],
Cell[7762, 244, 136, 3, 29, "Text",
  CellTags->{"CSSSave`", "Downloading"}],
Cell[7901, 249, 215, 7, 29, "Text",
  CellTags->{"CSSSave`", "Downloading"}],
Cell[8119, 258, 553, 12, 80, "Text",
  CellTags->{"CSSSave`", "Downloading"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[8709, 275, 115, 1, 70, "Section 1",
  CellTags->{"Installing and Using the package", "CSSSave`"}],
Cell[8827, 278, 437, 9, 80, "Text",
  CellTags->{"CSSSave`", "Installing and Using the package"}],
Cell[9267, 289, 118, 1, 29, "Text",
  CellTags->{"CSSSave`", "Installing and Using the package"}],
Cell[9388, 292, 106, 2, 35, "Input",
  CellTags->{"CSSSave`", "Installing and Using the package"}],
Cell[9497, 296, 482, 8, 63, "Text",
  CellTags->{"CSSSave`", "Installing and Using the package"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[10016, 309, 132, 1, 70, "Section 1",
  CellTags->{
  "Known Bugs / Limitations / Flaws", "CSSSave`", "CSSSave` bugs"}],

Cell[CellGroupData[{
Cell[10173, 314, 105, 1, 41, "Subsection",
  CellTags->{
  "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
Cell[10281, 317, 420, 10, 47, "Text",
  CellTags->{
  "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
Cell[10704, 329, 258, 5, 29, "Text",
  CellTags->{
  "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[10999, 339, 149, 1, 41, "Subsection",
  CellTags->{
  "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
Cell[11151, 342, 223, 5, 29, "Text",
  CellTags->{
  "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
Cell[11377, 349, 201, 4, 29, "Text",
  CellTags->{
  "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
Cell[11581, 355, 208, 3, 40, "Print",
  CellTags->{
  "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
Cell[11792, 360, 257, 5, 30, "Text",
  CellTags->{
  "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
Cell[12052, 367, 258, 5, 29, "Text",
  CellTags->{
  "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
Cell[12313, 374, 252, 5, 29, "Text",
  CellTags->{
  "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
Cell[12568, 381, 280, 5, 46, "Text",
  CellTags->{
  "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[12885, 391, 138, 1, 41, "Subsection",
  CellTags->{
  "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
Cell[13026, 394, 702, 16, 89, "Text",
  CellTags->{
  "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
Cell[13731, 412, 242, 5, 29, "Text",
  CellTags->{
  "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
Cell[13976, 419, 333, 6, 46, "Text",
  CellTags->{
  "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
Cell[14312, 427, 283, 5, 46, "Text",
  CellTags->{
  "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],

Cell[CellGroupData[{
Cell[14620, 436, 122, 1, 31, "Subsubsection",
  CellTags->{
  "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
Cell[14745, 439, 448, 10, 46, "Text",
  CellTags->{
  "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
Cell[15196, 451, 557, 9, 63, "Text",
  CellTags->{
  "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
Cell[15756, 462, 429, 9, 46, "Text",
  CellTags->{
  "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
Cell[16188, 473, 458, 8, 46, "Text",
  CellTags->{
  "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
Cell[16649, 483, 417, 7, 46, "Text",
  CellTags->{
  "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}],
Cell[17069, 492, 114, 1, 29, "Text",
  CellTags->{
  "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}]
}, Open  ]]
}, Open  ]],
Cell[17210, 497, 288, 8, 41, "Subsection",
  CellTags->{
  "CSSSave`", "Known Bugs / Limitations / Flaws", "CSSSave` bugs"}]
}, Closed]],

Cell[CellGroupData[{
Cell[17535, 510, 85, 1, 44, "Section 1",
  CellTags->{"History", "CSSSave`", "CSSSave` History"}],

Cell[CellGroupData[{
Cell[17645, 515, 102, 1, 41, "Subsection",
  CellTags->{"History", "CSSSave`", "CSSSave` History"}],
Cell[17750, 518, 113, 1, 29, "Text",
  CellTags->{"History", "CSSSave`", "CSSSave` History"}],
Cell[17866, 521, 108, 2, 35, "Input",
  CellTags->{"History", "CSSSave`", "CSSSave` History"}],
Cell[17977, 525, 176, 4, 29, "Text",
  CellTags->{"History", "CSSSave`", "CSSSave` History"}],
Cell[18156, 531, 225, 6, 29, "Text",
  CellTags->{"History", "CSSSave`", "CSSSave` History"}],
Cell[18384, 539, 250, 5, 46, "Text",
  CellTags->{"History", "CSSSave`", "CSSSave` History"}],
Cell[18637, 546, 344, 6, 63, "Text",
  CellTags->{"History", "CSSSave`", "CSSSave` History"}],
Cell[18984, 554, 198, 4, 29, "Text",
  CellTags->{"History", "CSSSave`", "CSSSave` History"}],
Cell[19185, 560, 634, 11, 99, "Text",
  CellTags->{"History", "CSSSave`", "CSSSave` History"}],
Cell[19822, 573, 640, 11, 99, "Text",
  CellTags->{"History", "CSSSave`", "CSSSave` History"}],
Cell[20465, 586, 521, 10, 63, "Text",
  CellTags->{"History", "CSSSave`", "CSSSave` History"}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[21035, 602, 112, 1, 44, "Section 1",
  CellTags->{"HelpBrowser", "CSSSave`"}],

Cell[CellGroupData[{
Cell[21172, 607, 518, 14, 63, "Text",
  CellGroupingRules->{"SectionGrouping", 60},
  CellTags->{"HelpBrowser", "CSSSave`"}],
Cell[21693, 623, 66, 1, 31, "ObjectName",
  CellTags->{"CSSSave", "CSSSave`"}],
Cell[21762, 626, 906, 28, 78, "Usage",
  CellTags->{"CSSSave", "CSSSave`"}],
Cell[22671, 656, 153, 5, 25, "Notes",
  CellTags->{"CSSSave", "CSSSave`"}],
Cell[22827, 663, 4741, 131, 102, "DefinitionBox3Col",
  CellTags->{"CSSSave", "CSSSave`"}],
Cell[27571, 796, 487, 17, 48, "Notes",
  CellTags->{"CSSSave", "CSSSave`"}],

Cell[CellGroupData[{
Cell[28083, 817, 79, 1, 40, "ExampleSection",
  CellTags->{"CSSSave", "CSSSave`"}],
Cell[28165, 820, 243, 5, 35, "ExampleText",
  CellTags->{"CSSSave", "CSSSave`"}],
Cell[28411, 827, 81, 2, 35, "Input",
  CellTags->{"CSSSave", "CSSSave`"}],
Cell[28495, 831, 91, 2, 35, "Input",
  CellTags->{"CSSSave", "CSSSave`"}],
Cell[28589, 835, 146, 4, 35, "ExampleText",
  CellTags->{"CSSSave", "CSSSave`"}],
Cell[28738, 841, 79, 2, 35, "Input",
  CellTags->{"CSSSave", "CSSSave`"}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[28866, 849, 194, 4, 27, "Text",
  CellGroupingRules->{"SectionGrouping", 60},
  CellTags->"CSSSave`"],
Cell[29063, 855, 110, 1, 31, "ObjectName",
  CellTags->{"HTMLSave extensions", "CSSSave`"}],
Cell[29176, 858, 105, 1, 25, "Notes",
  CellTags->{"HTMLSave extensions", "CSSSave`"}],
Cell[29284, 861, 862, 27, 78, "Usage",
  CellTags->{"HTMLSave extensions", "CSSSave`"}],
Cell[30149, 890, 242, 6, 25, "Notes",
  CellTags->{"HTMLSave extensions", "CSSSave`"}],
Cell[30394, 898, 6410, 164, 404, "DefinitionBox3Col",
  CellTags->{"HTMLSave extensions", "CSSSave`"}],
Cell[36807, 1064, 143, 3, 25, "Notes",
  CellTags->{"HTMLSave extensions", "CSSSave`"}],
Cell[36953, 1069, 144, 4, 53, "Input",
  CellTags->{"HTMLSave extensions", "CSSSave`"}],
Cell[37100, 1075, 242, 9, 25, "Notes",
  CellTags->{"HTMLSave extensions", "CSSSave`"}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[37391, 1090, 83, 1, 70, "Section 1",
  CellTags->{"patch", "CSSSave`"}],
Cell[37477, 1093, 334, 6, 46, "Text",
  CellTags->{"patch", "CSSSave`"}],
Cell[37814, 1101, 520, 12, 125, "Input",
  CellTags->{"patch", "CSSSave`"}],
Cell[38337, 1115, 298, 8, 47, "Text",
  CellTags->{"patch", "CSSSave`"}]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

